@@ -5,21 +5,21 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0300';
 
 use strictures 2;
 use List::SomeUtils qw(first_index);
 use MIDI::Drummer::Tiny ();
 use MIDI::RtMidi::ScorePlayer ();
 use Moo;
-use Types::Standard qw(ArrayRef Num Maybe);
+use Types::Standard qw(ArrayRef CodeRef Num Maybe);
 use namespace::clean;
 
 
 
 has rtc => (
     is  => 'ro',
-    isa => sub { die 'Invalid rtc' unless ref($_[0]) eq 'MIDI::RtController' },
+    isa => sub { die 'Invalid controller' unless ref($_[0]) eq 'MIDI::RtController' },
     required => 1,
 );
 
@@ -52,13 +52,24 @@ has bpm => (
 );
 
 
+has phrase => (
+    is      => 'rw',
+    isa     => CodeRef,
+    builder => 1,
+);
+
+sub _build_phrase {
+    return sub {
+        my (%args) = @_;
+        $args{drummer}->metronome4;
+    };
+}
+
+
 sub _drum_parts ($self, $note) {
     my $part;
     if ($note == 99) {
-        $part = sub {
-            my (%args) = @_;
-            $args{drummer}->metronome4;
-        };
+        $part = $self->phrase;
     }
     else {
         $part = sub {
@@ -103,7 +114,7 @@ MIDI::RtController::Filter::Drums - RtController drum filters
 
 =head1 VERSION
 
-version 0.0203
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -112,16 +123,24 @@ version 0.0203
   use MIDI::RtController ();
   use MIDI::RtController::Filter::Drums ();
 
-  my $rtc = MIDI::RtController->new(
-    input  => 'keyboard',
-    output => 'usb',
+  my $controller = MIDI::RtController->new(
+    input   => 'keyboard',
+    output  => 'usb',
+    verbose => 1,
   );
 
-  my $filter = MIDI::RtController::Filter::Drums->new(rtc => $rtc);
+  my $filter = MIDI::RtController::Filter::Drums->new(rtc => $controller);
 
-  $rtc->add_filter('drums', note_on => $filter->curry::drums);
+  $filter->phrase(\&my_phrase);
 
-  $rtc->run;
+  $controller->add_filter('drums', note_on => $filter->curry::drums);
+
+  $controller->run;
+
+  sub my_phrase {
+    my (%args) = @_;
+    $args{drummer}->metronome7;
+  }
 
 =head1 DESCRIPTION
 
@@ -133,7 +152,7 @@ drum filter and uses the 4/4 metronome for this.
 
 =head2 rtc
 
-  $rtc = $filter->rtc;
+  $controller = $filter->rtc;
 
 The required L<MIDI::RtController> instance provided in the
 constructor.
@@ -178,6 +197,15 @@ The beats per minute.
 
 Default: C<120>
 
+=head2 phrase
+
+  $filter->phrase(\&your_phrase);
+  $part = $filter->phrase();
+
+The subroutine given to this attribute takes a collection of named
+parameters to do its thing. Primarily, this is a
+L<MIDI::Drummer::Tiny> instance named "drummer."
+
 =head1 METHODS
 
 All filter methods must accept the object, a MIDI device name, a
